<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Place;
use App\Dept;
use App\PlaceImages;
use App\Http\Requests\StoreDept;
use App\Http\Requests\UpdateDept;

class DeptsController extends Controller {

    //
    function __construct(Place $Place, Dept $Dept, PlaceImages $PlaceImages) {
        $this->place = $Place;
        $this->dept = $Dept;
        $this->place_images = $PlaceImages;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        //
        $depts = $this->dept->getAll();
        return view('admin.depts.index', ['depts' => $depts]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create() {
        //
        return view('admin.depts.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreDept $request) {
        $this->dept->add($request);
        $message = trans('layout.add_suc');
        return back()->with(['message' => $message]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {
        //
        $dept = $this->dept->getById($id);

        return view('admin.depts.edit', ['dept' => $dept]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateDept $request, $id) {
        //
        $this->dept->edit($id, $request);
        $message = trans('layout.edit_suc');
        return redirect('admin/depts')->with(['message' => $message]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        //
        $dept = $this->dept->getById($id);
        foreach ($dept['Places'] as $place) {
            $this->place->remove($place['id']);
            $this->place_images->removeByPlace($place['id']);
        }
        $this->dept->remove($id);
        $message = trans('layout.delete_suc');
        return back()->with(['message' => $message]);
    }

}
