<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Place;
use App\Dept;
use App\PlaceImages;
use App\Http\Requests\StorePlace;
use App\Http\Requests\UpdatePlace;

class PlacesController extends Controller {

    //
    function __construct(Place $Place, Dept $Dept,PlaceImages $PlaceImages) {
        $this->place = $Place;
        $this->dept = $Dept;
        $this->place_images = $PlaceImages;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        //
        $places = $this->place->getAll();
        return view('admin.places.index', ['places' => $places]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create() {

        $depts = $this->dept->getList();
        $depts = array_add($depts, '', 'إختر القسم');
        $depts = array_reverse($depts, TRUE);

        $ratings = ratings();

        return view('admin.places.create', ['depts' => $depts, 'ratings' => $ratings]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StorePlace $request) {
        $file = $request['image'];
        $filename = str_random(5) . '.' . $file->getClientOriginalName();
        $destinationPath = public_path('upload/places/');
        $file->move($destinationPath, $filename);

        $new = $this->place->add($request, $filename);
        
        if (isset($request['images'])) {
            $images = $request['images'];
            foreach ($images as $img) {
                if ($img != "") {
                    $filename = str_random(5) . '.' . $img->getClientOriginalName();
                    $destinationPath = public_path('upload/places/');
                    $img->move($destinationPath, $filename);
                    $this->place_images->add($filename, $new);
                }
            }
        }
        
        $message = trans('layout.add_suc');
        return back()->with(['message' => $message]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        //
        $this->place_images->remove($id);
        $message = trans('layout.delete_suc');
        return back()->with(['message' => $message]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {
        //
        $place = $this->place->getById($id);

        $depts = $this->dept->getList();
        $depts = array_add($depts, '', 'إختر القسم');
        $depts = array_reverse($depts, TRUE);

        $ratings = ratings();

        return view('admin.places.edit', ['place' => $place, 'depts' => $depts, 'ratings' => $ratings]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdatePlace $request, $id) {
//        dd($request->rating);
        $filename = FALSE;
        if ($request->hasFile('image')) {
            $file = $request['image'];
            $filename = str_random(5) . '.' . $file->getClientOriginalName();
            $destinationPath = public_path('upload/place/');
            $file->move($destinationPath, $filename);
        }

        $this->place->edit($id, $request, $filename);
        
        if (isset($request['images'])) {
            $images = $request['images'];
            foreach ($images as $img) {
                if ($img != "") {
                    $filename = str_random(5) . '.' . $img->getClientOriginalName();
                    $destinationPath = public_path('upload/places/');
                    $img->move($destinationPath, $filename);
                    $this->place_images->add($filename, $id);
                }
            }
        }

        $message = trans('layout.edit_suc');
        return redirect('admin/places')->with(['message' => $message]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        //
        $this->place->remove($id);
        $this->place_images->removeByPlace($id);
        $message = trans('layout.delete_suc');
        return back()->with(['message' => $message]);
    }

}
