<?php

namespace App\Http\Controllers\Api;

use App\ClientOpinion;
use App\Contact;
use App\Dept;
use App\Faq;
use App\Offer;
use App\Place;
use App\Site;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Validator;
use Auth;

class ApiController extends Controller
{

    public function getDepts() {

        $data = Dept::IsActive()->orderBy('sort')->select('id', 'name')->get();

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function getDeptPlaces($dept_id) {

        $data = Place::IsActive()->where('dept_id', $dept_id)->select('id', 'title', 'image', 'rating')->get();
        $data['imagesPath'] = url('/').'/upload/places/';

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function showPlace($place_id) {

        $data = Place::with(['Images' => function ($q){
                        $q->select('place_id', 'image');
                    }])
                    ->findOrFail($place_id);

        $data['imagesPath'] = url('/').'/upload/places/';
        $data['address'] = $data['City']['name'] . ' - ' . $data['address'];

        $data->makeHidden(['active', 'created_at', 'updated_at', 'dept_id', 'city_id'])->toArray();
        $data->makeHidden('City')->toArray();

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function getFaq() {

        $data = Faq::select('title', 'details')->get();

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function getContacts() {

        $data = Site::select('email', 'phone', 'mobile', 'fax')->get();

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function search(Request $request) {

        $data = Place::where('title', 'LIKE', '%'.$request->q.'%')->select('id', 'title', 'image')->get();

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function getClientsOpinions() {

        $data = ClientOpinion::select('name', 'opinion')->get();

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function getOffers() {

        $data = Offer::IsActive()
                    ->with(['place' => function ($q){
                        $q->select('id', 'title', 'image', 'rating');
                    }])
                    ->select('place_id', 'percentage')
                    ->get();

        $data['imagesPath'] = url('/').'/upload/places/';

        return response()->json(['data' => $data, 'status' => 'done']);
    }

    public function contactUs(Request $request) {

        $rules = [
            'name' => 'required|max:255',
            'phone' => 'required|max:255',
            'email' => 'required|max:255',
            'title' => 'required|max:255',
            'message' => 'required',
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {

            $error_arr = validateRules($validator->errors(), $rules);

            return response()->json(['status' => 'error', 'message' => 'validation_error', 'data' => $error_arr]);
        }

        $message = new Contact;

        if ( $message->add($request) )
            return response()->json(['status' => 'done', 'message' => 'تم ارسال رسالتك بنجاح ..سوف يتم التواصل معك فى اقرب وقت']);

        return response()->json(['status' => 'done', 'message' => 'عفوا حدث خطا غير متوقع ...حاول مرا اخرى ']);
    }

//    public function login(Request $request){
//
//        $rules = [
//            'phone' => 'required',
//            'password' => 'required',
////            'device_id' => 'required'
//        ];
//
//        $validator = Validator::make($request->all(), $rules);
//
//        if ($validator->fails()) {
//
//            $error_arr = validateRules($validator->errors(), $rules);
//
//            return response()->json(['status' => 'error', 'message' => 'validation_error', 'data' => $error_arr]);
//        }
//
//        if (Auth::attempt(['phone' => $request->phone, 'password' => $request->password])) {
//
//            if (Auth::user()->active == 'no') {
//                return response()->json(['status' => 'error', 'message' => 'blocked_user', 'data' => 'تم ايقاف عضويتك من قبل الادارة']);
//            }
//
//            $user['id'] = Auth::user()->id;
//            $user['name'] = Auth::user()->name;
//            $user['username'] = Auth::user()->username;
//            $user['email'] = Auth::user()->email;
//            $user['phone'] = Auth::user()->phone;
//            $user['api_token'] = Auth::user()->api_token;
//
//            //save_device_id....
////            $this->createOrUpdateUserDevice($user['id'], $request->device_id);
//
//            return response()->json(['status' => 'done', 'data' => $user]);
//        }
//
//        return response()->json(['status' => 'error', 'message' => 'wrong_credential', 'data' => 'رقم هاتف أو كلمة مرور خاطئة']);
//    }
}